@@ -3,13 +3,15 @@ Main interface for codebuild service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codebuild import CodeBuildClient
+    from mypy_boto3_codebuild import CodeBuildClient
 
     session = boto3.Session()
 
     client: CodeBuildClient = boto3.client("codebuild")
     session_client: CodeBuildClient = session.client("codebuild")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
