@@ -3,8 +3,11 @@ Main interface for codebuild service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codebuild import (
+
+    from mypy_boto3_codebuild import CodeBuildClient
+    from mypy_boto3_codebuild import (
         DescribeTestCasesPaginator,
         ListBuildsPaginator,
         ListBuildsForProjectPaginator,
@@ -27,6 +30,7 @@ Usage::
     list_reports_for_report_group_paginator: ListReportsForReportGroupPaginator = client.get_paginator("list_reports_for_report_group")
     list_shared_projects_paginator: ListSharedProjectsPaginator = client.get_paginator("list_shared_projects")
     list_shared_report_groups_paginator: ListSharedReportGroupsPaginator = client.get_paginator("list_shared_report_groups")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
