@@ -3,9 +3,11 @@ Main interface for codebuild service type definitions.
 
 Usage::
 
-    from mypy_boto3.codebuild.type_defs import BuildArtifactsTypeDef
+    ```python
+    from mypy_boto3_codebuild.type_defs import BuildArtifactsTypeDef
 
     data: BuildArtifactsTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
